@@ -6,6 +6,7 @@ from vortex.handler.TupleActionProcessorProxy import TupleActionProcessorProxy
 
 def makeTupleActionProcessorProxy():
     return TupleActionProcessorProxy(
-                tupleActionProcessorName=chatActionProcessorName,
-                proxyToVortexName=peekServerName,
-                additionalFilt=chatFilt)
\ No newline at end of file
+        tupleActionProcessorName=chatActionProcessorName,
+        proxyToVortexName=peekServerName,
+        additionalFilt=chatFilt,
+    )
