@@ -9,5 +9,6 @@ def makeTupleActionProcessorHandler(mainController: MainController):
     processor = TupleActionProcessor(
         tupleActionProcessorName=chatActionProcessorName,
         additionalFilt=chatFilt,
-        defaultDelegate=mainController)
-    return processor
\ No newline at end of file
+        defaultDelegate=mainController,
+    )
+    return processor
